require_relative 'persistence'

module ArisControl
  class Bookkeeper
    attr_reader :persistence, :apps

    def initialize(persistence = default_persistence)
      @persistence = persistence
      @apps = persistence.load_apps
    end

    def list
      apps
    end

    def add(name, opts = {})
      env_vars = opts[:env_vars]
      app = apps[name] || {}
      apps[name] = app.dup.tap do |h|
        h['email']    = opts[:email] || app.fetch('email')
        h['ssh_key']  = opts[:ssh_key] if opts[:ssh_key]
        h['env_vars'] = with_upcased_keys(env_vars) if env_vars
      end
      persistence.store_apps(apps)
    end

    def add_env_vars(name, additional_env_vars = {})
      app = apps[name] or return
      env_vars = app['env_vars'] || {}
      app['env_vars'] = env_vars.merge(with_upcased_keys(additional_env_vars))
      persistence.store_apps(apps)
    end

    def delete(name)
      apps.delete(name)
      persistence.store_apps(apps)
    end

    def default_persistence
      ArisControl::Persistence.new
    end

    private

    def with_upcased_keys(hash)
      hash or return
      hash.each_with_object({}) {|(k,v),h| h[k.to_s.upcase] = v }
    end
  end
end
