require 'yaml'
require 'pathname'

module ArisControl
  class Persistence
    attr_reader :apps_file_path

    def initialize(apps_file_path = default_apps_file_path)
      @apps_file_path = Pathname.new(apps_file_path)
    end

    def store_apps(apps)
      apps ||= {}
      IO.binwrite(apps_file_path, serialized_apps(apps))
      apps
    end

    def load_apps
      store_apps({}) unless apps_file_path.exist?
      deserialized_apps(IO.binread(apps_file_path))
    end

    def default_apps_file_path
      '/opt/aris/config/apps.yml'
    end

    private

    def serialized_apps(apps)
      YAML.dump({ 'aris_apps' => apps })
    end

    def deserialized_apps(string)
      yaml = YAML.load(string) || {}
      yaml['aris_apps'] || {}
    end
  end
end
