require 'thor'
require 'pp'

class ArisControl::Thor < Thor
  desc 'add appname [opts]', 'adds/updates an aris app.'
  method_option :email,    type: :string, desc: 'The apps email address. Used for web login.'
  method_option :ssh_key,  type: :string, desc: 'The apps ssh public key. Used for git access via ssh.'
  method_option :env_vars, type: :hash,   desc: "WARNING. This overwrites all previously existing env_vars.\nThe apps app env vars. Env vars will be accessible inside the app via ENV[VAR-NAME]."
  def add(name)
    opts = Hash.new.tap do |o|
      o[:email]    = options[:email]
      o[:ssh_key]  = options[:ssh_key]  if options[:ssh_key]
      o[:env_vars] = options[:env_vars] if options[:env_vars]
    end
    bookkeeper.add(name, **opts)
    puts "Added/Updated app: #{name}, #{opts}"
    puts "-----------------------------"
    print_current_aris_apps
  end

  desc 'add-env-vars [opts]', 'Adds an env var to the given app.'
  method_option :env_vars, type: :hash, desc: 'The apps app env vars. Env vars will be accessible inside the app via ENV[VAR-NAME].'
  def add_env_vars(name)
    bookkeeper.add_env_vars(name, options[:env_vars])
    puts "Added/Updated app: #{name}, #{options}"
    puts "-----------------------------"
    print_current_aris_apps
  end

  desc 'delete name', 'Deletes aris app'
  def delete(name)
    bookkeeper.delete(name)
    puts "Removed app: #{name}"
    puts "-----------------------------"
    print_current_aris_apps
  end

  desc 'list', 'Lists current aris-apps'
  def list
    print_current_aris_apps
  end

  desc 'rollout', 'Runs ansible to provision the current apps.yml state'
  def rollout
    provsioner.rollout
    print_current_aris_apps
  end

  desc 'version', 'Prints out aris-control version'
  def version
    puts ArisControl::VERSION
  end

  private

  def print_current_aris_apps
    puts "Current aris app database"
    puts "-----------------------------"
    pp bookkeeper.list
  end

  def bookkeeper
    @bookkeeper ||= ArisControl::Bookkeeper.new
  end

  def provsioner
    @provsioner ||= ArisControl::Provisioner.new
  end
end
